pub fn normalize_dsc_for_event_spans(
event: &mut Event,
config: &NormalizationConfig<'_>,
)Expand description
Writes DSC attributes needed for dynamic sampling into the spans’ data.
pub fn normalize_dsc_for_event_spans(
event: &mut Event,
config: &NormalizationConfig<'_>,
)Writes DSC attributes needed for dynamic sampling into the spans’ data.