normalize_dsc_for_event_spans

Function normalize_dsc_for_event_spans 

pub fn normalize_dsc_for_event_spans(
    event: &mut Event,
    dsc: Option<EnrichedDsc<'_>>,
)
Writes DSC attributes needed for dynamic sampling into the spans’ data.

If sentry.dsc.trace_id is already present in a span’s data, the function does nothing for that span.